Calculate Indicators for WESP assessment site
calc_indicators.RdCalculate all Function and Benefit indicators for a site.
Arguments
- site
An object of type
wesp_site, as created withas.wesp_site().
calc_indicators.RdCalculate all Function and Benefit indicators for a site.
An object of type wesp_site, as created
with as.wesp_site().