Skip to contents

This dataset is created for the purpose of calibrating the WESP model. The script to process this data is available : data-raw/upload-calibration-data.R.

Usage

calibration_scores

Format

calibration_scores

A data frame with 99 rows and 7 columns:

ecoprovince

ecoprovince abbreviation

service

2 & 3 letter ISO country codes

year

Year

...

see developers