Load the data containing the responses to WESP form
load_wesp_data.RdThis file is usually an output from the R script at https://github.com/BCWF-Wetlands/WESP_Calculator, and includes answers to Office (OF), Field (F), and Stressor (S) questions.
load_wesp_data.RdThis file is usually an output from the R script at https://github.com/BCWF-Wetlands/WESP_Calculator, and includes answers to Office (OF), Field (F), and Stressor (S) questions.