calibration_scores.Rd
This dataset is created for the purpose of calibrating the WESP model. The script to process this data is available : data-raw/upload-calibration-data.R.
data-raw/upload-calibration-data.R
calibration_scores
A data frame with 99 rows and 7 columns:
ecoprovince abbreviation
2 & 3 letter ISO country codes
Year
see developers